#!/bin/bash

. config.sh

INTI_LDAP_ACCESS=changeAccess.ldif
INTI_LDAP_BASE=base.ldif
INTI_LDAP_SCHEMA=schema.ldif
INTI_LDAP_TMP=${INTI_TMP}ldap/

$INTI_ECHO -\> Running config_ldap.sh script
[ -d $INTI_LDAP_TMP ] || mkdir -p $INTI_LDAP_TMP
#trap "{ $INTI_ECHO Error during config_ldap.script, returned exit code: $?; exit $? }" ERR

dpkg-reconfigure slapd

$INTI_ECHO -\> Securing server for authenticated modification
$INTI_LDAPSEARCH -Y EXTERNAL -H ldapi:// -b cn=config "(&(objectClass=olcDatabaseConfig)(olcSuffix=dc=$INTI_DOMAIN,dc=$INTI_TLD))" > ${INTI_LDAP_TMP}output.txt
# Sets the fields on two lines on a single line
$INTI_SED -i ':a;N;$!ba;s/\n //g' ${INTI_LDAP_TMP}output.txt

# Write the config file
$INTI_CAT ${INTI_LDAP_TMP}output.txt | $INTI_GREP '^dn' >> ${INTI_LDAP_TMP}${INTI_LDAP_ACCESS}
$INTI_ECHO changetype: modify >> ${INTI_LDAP_TMP}${INTI_LDAP_ACCESS}
$INTI_ECHO delete: olcAccess >> ${INTI_LDAP_TMP}${INTI_LDAP_ACCESS}
$INTI_ECHO - >> ${INTI_LDAP_TMP}${INTI_LDAP_ACCESS}
$INTI_ECHO add: olcAccess >> ${INTI_LDAP_TMP}${INTI_LDAP_ACCESS}
$INTI_CAT ${INTI_LDAP_TMP}output.txt | $INTI_GREP olcAccess:\ {0} | $INTI_SED "s/\(olcAccess.*auth by\).*/\1 dn=\"cn=admin,dc=$INTI_DOMAIN,dc=$INTI_TLD\" write by * none/" >> ${INTI_LDAP_TMP}${INTI_LDAP_ACCESS}
$INTI_ECHO - >> ${INTI_LDAP_TMP}${INTI_LDAP_ACCESS}
$INTI_ECHO add: olcAccess >> ${INTI_LDAP_TMP}${INTI_LDAP_ACCESS}
$INTI_CAT ${INTI_LDAP_TMP}output.txt | $INTI_GREP olcAccess:\ {1} >> ${INTI_LDAP_TMP}${INTI_LDAP_ACCESS}
$INTI_ECHO - >> ${INTI_LDAP_TMP}${INTI_LDAP_ACCESS}
$INTI_ECHO add: olcAccess >> ${INTI_LDAP_TMP}${INTI_LDAP_ACCESS}
$INTI_CAT ${INTI_LDAP_TMP}output.txt | $INTI_GREP olcAccess:\ {2} | $INTI_SED "s/\(olcAccess.* \* by\).*/\1 self write by dn=\"cn=admin,dc=$INTI_DOMAIN,dc=$INTI_TLD\" write by * none/" >> ${INTI_LDAP_TMP}${INTI_LDAP_ACCESS}
$INTI_ECHO - >> ${INTI_LDAP_TMP}${INTI_LDAP_ACCESS}

# Write changes to database
$INTI_LDAPMODIFY -c -Y EXTERNAL -H ldapi:/// -f ${INTI_LDAP_TMP}${INTI_LDAP_ACCESS}
$INTI_ECHO -\> Changed access rules

# Copy courier-ldap schema
$INTI_CP data/authldap.schema /etc/ldap/schema

# Insert new schema
$INTI_ECHO -\> Adding Courier schema to configuration
$INTI_LDAPSEARCH -Y EXTERNAL -H ldapi:/// -b "cn=schema,cn=config" -LLL "(objectClass=*)" cn | $INTI_GREP cn:\ { | $INTI_SED -ne "s/cn.*{[0-9]*}\(.*\)/\1/p" > ${INTI_LDAP_TMP}output.txt
while read line; do
  [ -z "$line" ] && continue
  echo include /etc/ldap/schema/${line}.schema >> ${INTI_LDAP_TMP}${INTI_LDAP_SCHEMA}
done < ${INTI_LDAP_TMP}output.txt
echo include /etc/ldap/schema/authldap.schema >> ${INTI_LDAP_TMP}${INTI_LDAP_SCHEMA}

$INTI_SLAPTEST -f ${INTI_LDAP_TMP}${INTI_LDAP_SCHEMA} -F ${INTI_LDAP_TMP}
$INTI_SED -i "0,/dn:.*authldap/ s/authldap/authldap,cn=schema,cn=config/" ${INTI_LDAP_TMP}cn\=config/cn\=schema/cn\=\{*\}authldap.ldif
$INTI_HEAD -n -7 ${INTI_LDAP_TMP}cn\=config/cn\=schema/cn\=\{*\}authldap.ldif > ${INTI_LDAP_TMP}tmp.ldif
$INTI_MV ${INTI_LDAP_TMP}tmp.ldif ${INTI_LDAP_TMP}cn\=config/cn\=schema/cn\=\{*\}authldap.ldif
$INTI_LDAPADD -Y EXTERNAL -H ldapi:/// -f ${INTI_LDAP_TMP}cn\=config/cn\=schema/cn\=\{*\}authldap.ldif

# Config base structure
$INTI_ECHO -\> Building basic structure with admin account
$INTI_CP data/skel_ldap.txt ${INTI_LDAP_TMP}${INTI_LDAP_BASE}
$INTI_SED -i "s/\$domaine/$INTI_DOMAIN/g" ${INTI_LDAP_TMP}${INTI_LDAP_BASE}
$INTI_SED -i "s/\$tld/$INTI_TLD/g" ${INTI_LDAP_TMP}${INTI_LDAP_BASE}
PASS=""
while [ -z "$PASS" ]; do
  $INTI_ECHO -n "Enter password for admin:"
  read -s PASS
  $INTI_ECHO ""
done
HASH=`slappasswd -s $PASS -h {SSHA}`
$INTI_SED -i "s/\$pass/$HASH/g" ${INTI_LDAP_TMP}${INTI_LDAP_BASE}

$INTI_LDAPADD -D "cn=admin,dc=$INTI_DOMAIN,dc=$INTI_TLD" -w $INTI_LDAP_PW -h localhost -f ${INTI_LDAP_TMP}${INTI_LDAP_BASE}
