#!/bin/bash

. config.sh

INTI_POST_TMP=${INTI_TMP}postfix/
INTI_POST_MAIN_CONF=main.txt
INTI_LDAP_ACC=/etc/postfix/ldap_accounts.cf
INTI_LDAP_ALIASES=/etc/postfix/ldap_aliases.cf

$INTI_ECHO -\> Running config_postfix.sh script
[ -d $INTI_POST_TMP ] || mkdir -p $INTI_POST_TMP

# Creating vmail user and group
$INTI_ECHO -\> Creating vmail user and group
groupadd vmail
useradd -g vmail -d /home/vmail -s /bin/false -m vmail
VUID=`cat /etc/passwd | grep vmail | cut -d: -f3`
VGID=`cat /etc/group | grep vmail | cut -d: -f3`

# Add configuration to postfix main.cf
$INTI_ECHO -\> Adding configuration to postfix\'s main.cf
$INTI_ECHO "smtpd_banner = mail.${INTI_DOMAIN}.$INTI_TLD" >> ${INTI_POST_TMP}${INTI_POST_MAIN_CONF}
$INTI_ECHO "virtual_mailbox_base = /home/vmail" >> ${INTI_POST_TMP}${INTI_POST_MAIN_CONF}
$INTI_ECHO "virtual_mailbox_domains = ${INTI_DOMAIN}.$INTI_TLD" >> ${INTI_POST_TMP}${INTI_POST_MAIN_CONF}
$INTI_ECHO "virtual_mailbox_maps = ldap:$INTI_LDAP_ACC" >> ${INTI_POST_TMP}${INTI_POST_MAIN_CONF}
$INTI_ECHO "virtual_alias_maps = ldap:$INTI_LDAP_ALIASES" >> ${INTI_POST_TMP}${INTI_POST_MAIN_CONF}
$INTI_ECHO "virtual_minimum_uid = 100" >> ${INTI_POST_TMP}${INTI_POST_MAIN_CONF}
$INTI_ECHO "virtual_gid_maps = static:$VGID" >> ${INTI_POST_TMP}${INTI_POST_MAIN_CONF}
$INTI_ECHO "virtual_uid_maps = static:$VUID" >> ${INTI_POST_TMP}${INTI_POST_MAIN_CONF}

$INTI_ECHO "" >> /etc/postfix/main.cf
$INTI_ECHO "#Intimail params generated automatically" >> /etc/postfix/main.cf
while read line; do
  [ -z "$line" ] && continue
  TEST=`$INTI_ECHO $line | cut -d= -f1`
  TEST=`$INTI_SED -n "/^$TEST/p" /etc/postfix/main.cf`
  [ -z "$TEST" ] || $INTI_SED -i "s/$TEST/#$TEST/g" /etc/postfix/main.cf
  $INTI_ECHO $line >> /etc/postfix/main.cf
done < ${INTI_POST_TMP}${INTI_POST_MAIN_CONF}

# Creating postfix ldap accounts lookup config file
$INTI_ECHO -\> "Creating $INTI_LDAP_ACC"
$INTI_ECHO "server_host = localhost" >> $INTI_LDAP_ACC
$INTI_ECHO "server_port = 389" >> $INTI_LDAP_ACC
$INTI_ECHO "search_base = dc=people,dc=mail,dc=$INTI_DOMAIN,dc=$INTI_TLD" >> $INTI_LDAP_ACC
$INTI_ECHO "query_filter = (&(objectClass=CourierMailAccount)(mail=%s))" >> $INTI_LDAP_ACC
$INTI_ECHO "result_attribute = mailbox" >> $INTI_LDAP_ACC
$INTI_ECHO "bind = yes" >> $INTI_LDAP_ACC
$INTI_ECHO "bind_dn = cn=admin,dc=$INTI_DOMAIN,dc=$INTI_TLD" >> $INTI_LDAP_ACC
$INTI_ECHO "bind_pw = $INTI_LDAP_PW" >> $INTI_LDAP_ACC
$INTI_ECHO "version = 3" >> $INTI_LDAP_ACC

# Creating postfix ldap aliases lookup config file
$INTI_ECHO -\> "Creating $INTI_LDAP_ALIASES"
$INTI_ECHO "server_host = localhost" >> $INTI_LDAP_ALIASES
$INTI_ECHO "server_port = 389" >> $INTI_LDAP_ALIASES
$INTI_ECHO "search_base = dc=groups,dc=mail,dc=$INTI_DOMAIN,dc=$INTI_TLD" >> $INTI_LDAP_ALIASES
$INTI_ECHO "query_filter = (&(objectClass=CourierMailAlias)(mail=%s))" >> $INTI_LDAP_ALIASES
$INTI_ECHO "result_attribute = maildrop" >> $INTI_LDAP_ALIASES
$INTI_ECHO "bind = yes" >> $INTI_LDAP_ALIASES
$INTI_ECHO "bind_dn = cn=admin,dc=$INTI_DOMAIN,dc=$INTI_TLD" >> $INTI_LDAP_ALIASES
$INTI_ECHO "bind_pw = $INTI_LDAP_PW" >> $INTI_LDAP_ALIASES
$INTI_ECHO "version = 3" >> $INTI_LDAP_ALIASES

